IsolateDevServer class
- Inheritance
-
- Object
- ChangeNotifier
- IsolateDevServer
Constructors
Properties
- eventListenner ↔ void Function(String, Map)?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hostPort → ReceivePort
-
final
- hostSendPort ↔ SendPort?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverConnected ↔ bool
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
connected(
) → dynamic -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
invokeMethod(
String method, Map params) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
start(
) → dynamic -
stop(
) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
final